@@ -12,11 +12,11 @@ IO::Die - Namespaced, error-checked I/O
 
 =head1 VERSION
 
-Version 0.046
+Version 0.047
 
 =cut
 
-our $VERSION = '0.046';
+our $VERSION = '0.047';
 
 #----------------------------------------------------------------------
 #PROTECTED
@@ -24,7 +24,7 @@ our $VERSION = '0.046';
 #Override in subclasses as needed
 sub _CREATE_ERROR {
     shift;
-    return shift() . ": @_";
+    return shift() . ": " . join( ' ', map { defined() ? $_ : q<> } @_ );
 }
 
 sub _DO_WITH_ERROR { die $_[1] }
